@@ -125,7 +125,7 @@ void WaylandOutput::updateKScreenOutput(KScreen::OutputPtr &output)
     output->setEnabled(m_output->enabled() == KWayland::Client::OutputDevice::Enablement::Enabled);
     output->setConnected(true);
     output->setPrimary(true); // FIXME: wayland doesn't have the concept of a primary display
-    output->setName(m_output->manufacturer() + QStringLiteral("-") + m_output->model());
+    output->setName(m_output->model());
     // Physical size
     output->setSizeMm(m_output->physicalSize());
     output->setPos(m_output->globalPosition());
@@ -138,7 +138,7 @@ void WaylandOutput::updateKScreenOutput(KScreen::OutputPtr &output)
         const QString modename = modeName(m);
         QString modeid = QString::number(m.id);
         if (modeid.isEmpty()) {
-            qCWarning(KSCREEN_WAYLAND) << "Could not create mode id from" << m.id << ", using" << modename << "instead.";
+            qCDebug(KSCREEN_WAYLAND) << "Could not create mode id from" << m.id << ", using" << modename << "instead.";
             modeid = modename;
         }
         if (m_modeIdMap.keys().contains(modeid)) {
